@@ -14,7 +14,7 @@ import stomp.connect as connect
 import stomp.listener as listener
 import stomp.logging as logging
 
-__version__ = (8, 0, 0)
+__version__ = (8, 1, 0)
 
 ##
 # Alias for STOMP 1.0 connections.
@@ -33,6 +33,8 @@ StompConnection11 = Connection11
 #
 Connection12 = connect.StompConnection12
 StompConnection12 = Connection12
+WSConnection = adapter.ws.WSStompConnection
+WSStompConnection = WSConnection
 
 ##
 # Default connection alias (STOMP 1.1).
