@@ -132,7 +132,7 @@ class Protocol10(ConnectionListener):
         :param keyword_headers: any additional headers the broker requires
         """
         if not self.transport.is_connected():
-            logging.debug("Not sending disconnect, already disconnected")
+            logging.debug("not sending disconnect, already disconnected")
             return
         headers = utils.merge_headers([headers, keyword_headers])
         rec = receipt or utils.get_uuid()
@@ -351,7 +351,7 @@ class Protocol11(HeartbeatListener, ConnectionListener):
         :param keyword_headers: any additional headers the broker requires
         """
         if not self.transport.is_connected():
-            logging.debug("Not sending disconnect, already disconnected")
+            logging.debug("not sending disconnect, already disconnected")
             return
         headers = utils.merge_headers([headers, keyword_headers])
         rec = receipt or utils.get_uuid()
