@@ -2,13 +2,11 @@
 from the actual STOMP protocol
 """
 
-import datetime
 import errno
 import math
 import random
 import sys
 import time
-import warnings
 from io import BytesIO
 from time import monotonic
 
@@ -27,18 +25,13 @@ except ImportError:
 try:
     import ssl
     from ssl import SSLError
-    DEFAULT_SSL_VERSION = ssl.PROTOCOL_TLS
+    DEFAULT_SSL_VERSION = ssl.PROTOCOL_TLS_CLIENT
 except (ImportError, AttributeError):
     ssl = None
     class SSLError(object):
         pass
     DEFAULT_SSL_VERSION = None
 
-try:
-    import OpenSSL
-except ImportError:
-    OpenSSL = None
-
 
 import stomp.exception as exception
 import stomp.listener
@@ -46,21 +39,6 @@ from stomp.utils import *
 from stomp import logging
 
 
-def check_ssl_certificate(host_and_port):
-    '''
-    Check the expiry date of the certificate presented by the host/port.
-    '''
-    if OpenSSL:
-        host, port = host_and_port
-        cert = ssl.get_server_certificate((host, port))
-        x509 = OpenSSL.crypto.load_certificate(OpenSSL.crypto.FILETYPE_PEM, cert)
-        dt = datetime.datetime.strptime(x509.get_notAfter().decode().replace('Z',''), "%Y%m%d%H%M%S")
-        valid_cert = dt > datetime.datetime.now()
-        if not valid_cert:
-            logging.info("SSL certificate for %s:%s expired on %s", host, port, dt)
-        assert valid_cert
-
-
 class BaseTransport(stomp.listener.Publisher):
     """
     Base class for transport classes providing support for listeners, threading overrides,
@@ -129,7 +107,7 @@ class BaseTransport(stomp.listener.Publisher):
         self.running = True
         self.attempt_connection()
         receiver_thread = self.create_thread_fc(self.__receiver_loop)
-        logging.info("Created thread %s using func %s", receiver_thread, self.create_thread_fc)
+        logging.debug("created thread %s using func %s", receiver_thread, self.create_thread_fc)
         self.notify("connecting")
 
     def stop(self):
@@ -208,12 +186,10 @@ class BaseTransport(stomp.listener.Publisher):
             if frame_type == "message":
                 self.notify("before_message", f)
             if logging.isEnabledFor(logging.DEBUG):
-                logging.debug("Received frame: %r, headers=%r, body=%r", f.cmd, f.headers, f.body)
-            else:
-                logging.info("Received frame: %r, len(body)=%r", f.cmd, length(f.body))
+                logging.debug("received frame: %r, headers=%r, body=%r", f.cmd, f.headers, f.body)
             self.notify(frame_type, f)
         else:
-            logging.warning("Unknown response frame type: '%s' (frame length was %d)", frame_type, length(frame_str))
+            logging.warning("unknown response frame type: '%s' (frame length was %d)", frame_type, length(frame_str))
 
     def notify(self, frame_type, frame=None):
         """
@@ -288,9 +264,7 @@ class BaseTransport(stomp.listener.Publisher):
         packed_frame = pack(lines)
 
         if logging.isEnabledFor(logging.DEBUG):
-            logging.debug("Sending frame: %s", clean_lines(lines))
-        else:
-            logging.info("Sending frame: %r", frame.cmd or "heartbeat")
+            logging.debug("sending frame: %s", clean_lines(lines))
         self.send(packed_frame)
 
     def send(self, encoded_frame):
@@ -347,7 +321,7 @@ class BaseTransport(stomp.listener.Publisher):
         """
         Main loop listening for incoming data.
         """
-        logging.info("Starting receiver loop (%s)", threading.current_thread())
+        logging.debug("starting receiver loop (%s)", threading.current_thread())
         notify_disconnected = True
         try:
             while self.running:
@@ -380,7 +354,7 @@ class BaseTransport(stomp.listener.Publisher):
             with self.__receiver_thread_exit_condition:
                 self.__receiver_thread_exited = True
                 self.__receiver_thread_exit_condition.notify_all()
-            logging.info("Receiver loop ended")
+            logging.debug("receiver loop ended")
             self.notify("receiver_loop_completed")
             if notify_disconnected and not self.notified_on_disconnect:
                 self.notify("disconnected")
@@ -533,7 +507,7 @@ class Transport(BaseTransport):
         BaseTransport.__init__(self, auto_decode, encoding, is_eol_fc)
 
         if host_and_ports is None:
-            logging.debug("No hosts_and_ports specified, adding default localhost")
+            logging.debug("no hosts_and_ports specified, adding default localhost")
             host_and_ports = [("localhost", 61613)]
 
         sorted_host_and_ports = []
@@ -622,7 +596,7 @@ class Transport(BaseTransport):
                     _, e, _ = sys.exc_info()
                     # ignore when socket already closed
                     if get_errno(e) != errno.ENOTCONN:
-                        logging.warning("Unable to issue SHUT_RDWR on socket because of error '%s'", e)
+                        logging.warning("unable to issue SHUT_RDWR on socket because of error '%s'", e)
 
         #
         # split this into a separate check, because sometimes the socket is nulled between shutdown and this call
@@ -632,7 +606,7 @@ class Transport(BaseTransport):
                 self.socket.close()
             except socket.error:
                 _, e, _ = sys.exc_info()
-                logging.warning("Unable to close socket because of error '%s'", e)
+                logging.warning("unable to close socket because of error '%s'", e)
         self.current_host_and_port = None
         self.socket = None
         if not self.notified_on_disconnect:
@@ -648,7 +622,7 @@ class Transport(BaseTransport):
                     self.socket.sendall(encoded_frame)
             except Exception:
                 _, e, _ = sys.exc_info()
-                logging.error("Error sending frame", exc_info=True)
+                logging.error("error sending frame", exc_info=True)
                 raise e
         else:
             raise exception.NotConnectedException()
@@ -678,12 +652,12 @@ class Transport(BaseTransport):
         self.socket = None
 
     def __enable_keepalive(self):
-        def try_setsockopt(sock, name, fam, opt, val):
+        def try_setsockopt(sock, name, fam, opt, val=None):
             if val is None:
                 return True  # no value to set always works
             try:
                 sock.setsockopt(fam, opt, val)
-                logging.info("keepalive: set %r option to %r on socket", name, val)
+                logging.debug("keepalive: set %r option to %r on socket", name, val)
             except:
                 logging.error("keepalive: unable to set %r option to %r on socket", name, val)
                 return False
@@ -709,19 +683,19 @@ class Transport(BaseTransport):
             if LINUX_KEEPALIVE_AVAIL:
                 ka_sig = "linux"
                 ka_args = None
-                logging.info("keepalive: autodetected linux-style support")
+                logging.debug("keepalive: autodetected linux-style support")
             elif MAC_KEEPALIVE_AVAIL:
                 ka_sig = "mac"
                 ka_args = None
-                logging.info("keepalive: autodetected mac-style support")
+                logging.debug("keepalive: autodetected mac-style support")
             else:
                 logging.error("keepalive: unable to detect any implementation, DISABLED!")
                 return
 
         if ka_sig == "linux":
-            logging.info("keepalive: activating linux-style support")
+            logging.debug("keepalive: activating linux-style support")
             if ka_args is None:
-                logging.info("keepalive: using system defaults")
+                logging.debug("keepalive: using system defaults")
                 ka_args = (None, None, None)
             ka_idle, ka_intvl, ka_cnt = ka_args
             if try_setsockopt(self.socket, "enable", SOL_SOCKET, SO_KEEPALIVE, 1):
@@ -729,9 +703,9 @@ class Transport(BaseTransport):
                 try_setsockopt(self.socket, "interval", SOL_TCP, TCP_KEEPINTVL, ka_intvl)
                 try_setsockopt(self.socket, "count", SOL_TCP, TCP_KEEPCNT, ka_cnt)
         elif ka_sig == "mac":
-            logging.info("keepalive: activating mac-style support")
+            logging.debug("keepalive: activating mac-style support")
             if ka_args is None:
-                logging.info("keepalive: using system defaults")
+                logging.debug("keepalive: using system defaults")
                 ka_args = (3,)
             ka_intvl = ka_args
             if try_setsockopt(self.socket, "enable", SOL_SOCKET, SO_KEEPALIVE, 1):
@@ -747,12 +721,12 @@ class Transport(BaseTransport):
         sleep_exp = 1
         connect_count = 0
 
-        logging.info("attempt reconnection (%s, %s, %s)", self.running, self.socket, connect_count)
+        logging.debug("attempt reconnection (%s, %s, %s)", self.running, self.socket, connect_count)
         while self.running and self.socket is None and (connect_count < self.__reconnect_attempts_max or
                                                         self.__reconnect_attempts_max == -1):
             for host_and_port in self.__host_and_ports:
                 try:
-                    logging.info("Attempting connection to host %s, port %s", host_and_port[0], host_and_port[1])
+                    logging.debug("attempting connection to host %s, port %s", host_and_port[0], host_and_port[1])
                     if self.__bind_host_port:
                         self.socket = socket.create_connection(host_and_port, self.__timeout, self.__bind_host_port)
                     else:
@@ -761,7 +735,6 @@ class Transport(BaseTransport):
                     need_ssl = self.__need_ssl(host_and_port)
 
                     if need_ssl:  # wrap socket
-                        check_ssl_certificate(host_and_port)
                         ssl_params = self.get_ssl(host_and_port)
                         tls_context = ssl.SSLContext(DEFAULT_SSL_VERSION)
                         if ssl_params["ca_certs"]:
@@ -781,11 +754,11 @@ class Transport(BaseTransport):
                             if cert_validation is None or cert_validation == ssl.CERT_NONE:
                                 tls_context.check_hostname = False
                             tls_context.verify_mode = cert_validation
-                            logging.info("Wrapping SSL socket")
+                            logging.debug("wrapping SSL socket")
                             self.socket = tls_context.wrap_socket(self.socket, server_hostname=host_and_port[0])
                         else:
                             # Old-style wrap_socket where we don't have a modern SSLContext (so no SNI)
-                            logging.info("Wrapping SSL socket (old style)")
+                            logging.debug("wrapping SSL socket (old style)")
                             self.socket = ssl.wrap_socket(
                                 self.socket,
                                 keyfile=ssl_params["key_file"],
@@ -809,12 +782,12 @@ class Transport(BaseTransport):
                             raise SSLError("Server certificate validation failed: %s", errmsg)
 
                     self.current_host_and_port = host_and_port
-                    logging.info("Established connection to host %s, port %s", host_and_port[0], host_and_port[1])
+                    logging.info("established connection to host %s, port %s", host_and_port[0], host_and_port[1])
                     break
                 except (OSError, AssertionError):
                     self.socket = None
                     connect_count += 1
-                    logging.warning("Could not connect to host %s, port %s", host_and_port[0], host_and_port[1],
+                    logging.warning("could not connect to host %s, port %s", host_and_port[0], host_and_port[1],
                                     exc_info=logging.verbose)
 
             if self.socket is None:
@@ -823,7 +796,7 @@ class Transport(BaseTransport):
                                        * math.pow(1.0 + self.__reconnect_sleep_increase, sleep_exp)))
                                   * (1.0 + random.random() * self.__reconnect_sleep_jitter))
                 sleep_end = monotonic() + sleep_duration
-                logging.debug("Sleeping for %.1f seconds before attempting reconnect", sleep_duration)
+                logging.debug("sleeping for %.1f seconds before attempting reconnect", sleep_duration)
                 while self.running and monotonic() < sleep_end:
                     time.sleep(0.2)
 
