@@ -1,8 +1,3 @@
-import time
-import unittest
-
-import pytest
-
 from stomp.__main__ import StompCLI
 from .testutils import *
 
@@ -10,7 +5,7 @@ from .testutils import *
 username = get_default_user()
 password = get_default_password()
 
-(sslhost, sslport) = get_default_ssl_host()[0]
+(sslhost, sslport) = get_ssl_host()[0]
 
 
 class TestSSLCLI(object):
@@ -35,4 +30,4 @@ class TestSSLCLI(object):
         teststdout.expect("Unsubscribing from '/queue/testsubscribe'")
         cli.onecmd("unsubscribe /queue/testsubscribe")
         teststdout.expect("Shutting down, please wait")
-        cli.onecmd("quit")
\ No newline at end of file
+        cli.onecmd("quit")
