@@ -1,5 +1,4 @@
 import importlib
-import logging
 import platform
 import traceback
 import xml.dom.minidom
@@ -7,6 +6,7 @@ import xml.dom.minidom
 import stomp
 from stomp.exception import *
 from stomp.listener import *
+from stomp import logging
 from .testutils import *
 
 
@@ -130,7 +130,7 @@ class TestNoResponseConnectionKill(object):
             conn.connect(wait=True)
             pytest.fail("Shouldn't happen")
         except ConnectFailedException:
-            logging.info("Received connect failed - test success")
+            logging.info("received connect failed - test success")
         except Exception as e:
             logging.error(e)
             pytest.fail("Shouldn't happen, error %s" % e)
@@ -168,6 +168,8 @@ class TestMiscellaneousLogic(object):
 
         # just check if there was a received heartbeat calculated
         assert hl.received_heartbeat > 0
+        # Shut down the heartbeat thread so it doesn't go into a busy loop
+        hl.on_disconnected()
 
     def test_original_headers(self, conn2):
         listener = conn2.get_listener("testlistener")
