@@ -1,7 +1,3 @@
-import time
-
-import pytest
-
 import stomp
 from stomp.listener import *
 from .testutils import *
@@ -16,6 +12,7 @@ def conn():
     yield conn
     conn.disconnect(receipt=None)
 
+
 class Test10Connect(object):
 
     def testsend10(self, conn):
