@@ -2,6 +2,7 @@
 
 from configparser import RawConfigParser
 import json
+import os
 import sys
 import time
 from subprocess import run, PIPE
@@ -53,6 +54,10 @@ def get_default_password():
 def get_ipv6_host():
     if config.has_option("ipv6", "host"):
         host = config.get("ipv6", "host")
+    elif os.environ.get('CONTAINERS_RUNROOT'):
+        # Running under "podman unshare"
+        result = run(["podman", "inspect", "stomppy", "-f", "{{.NetworkSettings.Networks.stomptest.GlobalIPv6Address}}"], stdout=PIPE)
+        host = result.stdout.decode("utf-8").strip()
     else:
         result = run(["docker", "ps", "-f", "name=stomppy", "--format", "{{.ID}}"], stdout=PIPE)
         container_id = result.stdout.decode("utf-8").rstrip()
@@ -89,6 +94,12 @@ def get_rabbitmq_host():
     return [(get_environ("RABBITMQ_HOST") or host, int(get_environ("RABBITMQ_PORT") or port))]
 
 
+def get_rabbitmq_ws_host():
+    host = config.get("rabbitmq_ws", "host")
+    port = config.get("rabbitmq_ws", "port")
+    return [(get_environ("RABBITMQ_WS_HOST") or host, int(get_environ("RABBITMQ_WS_PORT") or port))]
+
+
 def get_rabbitmq_user():
     user = config.get("rabbitmq", "user")
     return get_environ("RABBITMQ_USER") or user
@@ -125,7 +136,7 @@ class StubStompServer(object):
         self.frames = []
 
     def start(self):
-        logging.info("Starting stomp server")
+        logging.info("starting stomp server")
         self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         self.s.bind((self.host, self.port))
@@ -135,10 +146,10 @@ class StubStompServer(object):
         thread.daemon = True
         thread.start()
         self.stopped = False
-        logging.info("Stomp server started")
+        logging.info("stomp server started")
 
     def stop(self):
-        logging.info("Stopping test server")
+        logging.info("stopping test server")
         if self.conn:
             try:
                 self.conn.shutdown(socket.SHUT_WR)
@@ -151,7 +162,7 @@ class StubStompServer(object):
         self.conn = None
         self.s = None
         self.stopped = True
-        logging.info("Connection stopped")
+        logging.info("connection stopped")
 
     def get_next_frame(self):
         if len(self.frames) > 0:
@@ -159,7 +170,7 @@ class StubStompServer(object):
             del self.frames[0]
             return rtn
         else:
-            return ''
+            return None
 
     def add_frame(self, frame):
         self.frames.append(frame)
@@ -173,7 +184,7 @@ class StubStompServer(object):
                 if self.conn is None:
                     break
                 if frame is not None:
-                    logging.info("Stompserver sending frame %s", frame)
+                    logging.info("stompserver sending frame %s", frame)
                     self.conn.send(encode(frame))
             except Exception:
                 _, e, _ = sys.exc_info()
@@ -185,7 +196,7 @@ class StubStompServer(object):
         except:
             pass
         self.stopped = True
-        logging.info("Run loop completed")
+        logging.info("run loop completed")
 
 
 class StubStdin(object):
@@ -233,7 +244,7 @@ def validate_send(conn, connections=1, messages=1, errors=0):
 
 def is_inside_travis():
     if os.environ.get("TRAVIS", "false") == "true":
-        logging.info("Not running test inside travis")
+        logging.info("not running test inside travis")
         return True
     return False
 
@@ -248,4 +259,4 @@ def next_free_port(port=1024, max_port=65535):
             return port
         except OSError:
             port += 1
-    raise IOError("no free ports")
\ No newline at end of file
+    raise IOError("no free ports")
